# Changelog
## 0.9.0 (2023-08-12)
- Migrated to pyproject.toml
- Added wayland support with a new command firefox_newuser_wayland

## 0.8.0 (2022-11-13)
- Sync directory in now created if it doesn't exist.

## 0.7.0 (2022-11-02)
- Personal --sync directory now works

## 0.6.0 (2022-11-02)
- Sync files feature improved. You can download files in any place  on firefox_newuser home

## 0.5.0 (2022-09-20)
- Changed to a python app

## 0.4.0 (2022-09-14)
- Added sync directory.
- .cache/doc is unmounted now cache/doc

## 0.3.0 (2021-12-29)
- Added DISPLAY environment variable

## 0.2.0 (2020-01-09)
- Process information on exit is improved

## 0.1.0 (2020-01-09)
- Imported from old scripts